@@ -61,6 +61,7 @@
 
 #include <kio/thumbcreator.h>
 #include <kio/thumbsequencecreator.h>
+#include <kio/previewjob.h>
 
 #include <iostream>
 #include <QDirIterator>
@@ -323,7 +324,7 @@ void ThumbnailProtocol::get(const QUrl &url)
         QByteArray imgData;
         QDataStream stream( &imgData, QIODevice::WriteOnly );
         //qDebug() << "IMAGE TO SHMID";
-        void *shmaddr = shmat(shmid.toInt(), 0, 0);
+        void *shmaddr = shmat(shmid.toInt(), nullptr, 0);
         if (shmaddr == (void *)-1) {
             error(KIO::ERR_INTERNAL, i18n("Failed to attach to shared memory segment %1", shmid));
             return;
@@ -631,7 +632,7 @@ ThumbCreator* ThumbnailProtocol::getThumbCreator(const QString& plugin)
             }
         }
         if (!creator) {
-            return 0;
+            return nullptr;
         }
 
         m_creators.insert(plugin, creator);
@@ -662,10 +663,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
 {
     if (m_enabledPlugins.isEmpty()) {
         const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
-        m_enabledPlugins = globalConfig.readEntry("Plugins", QStringList()
-                                                             << "imagethumbnail"
-                                                             << "jpegthumbnail"
-                                                             << "videopreview");
+        m_enabledPlugins = globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins());
     }
 
     const QMimeDatabase db;
